ESIBD Explorer
==============

A comprehensive data acquisition and analysis tool for Electrospray Ion-Beam Deposition experiments and beyond.

.. image:: https://readthedocs.org/projects/esibd-explorer/badge/?version=latest
   :target: https://esibd-explorer.readthedocs.io/en/latest/index.html
   :alt: Documentation Status

.. github will cash the logo so updates may only become effective after a few days, the link will still point to the lates version
.. image:: https://badge.fury.io/py/esibd-explorer.svg
   :target: https://badge.fury.io/py/esibd-explorer
   :alt: ESIBD Explorer on PyPI

.. figure:: https://github.com/ioneater/ESIBD-Explorer/blob/main/docs/pages/2023-10_ESIBD_GUI_plain.png?raw=true

   **ESIBD Explorer user interface.** The ESIBD Explorer controls all aspects of an Electrospray Ion-Beam Deposition (ESIBD) experiment, 
   including optimization and characterization of the ion-beam energy, beam intensity, and beam size, as well as monitoring of the deposition. 
   At each step, results and metadata are saved to document the experiment and allow for later reproduction of all experimental conditions.

Documentation
-------------

Read the documentation online at http://esibd-explorer.rtfd.io/

..
   Optionally, to build the documentation yourself from the ``docs/`` folder::
.. 
  pip install sphinx
  cd docs/
  make html

Installation
------------

Install directly from the `Python Package Index <https://pypi.org/project/esibd-explorer>`_ using pip::

   pip install esibd-explorer

Run the program using::

   python -m esibd.explorer

Visit the `documentation <https://esibd-explorer.readthedocs.io/en/latest/pages/install.html>`_ for alternative methods. 

Source code
-----------

https://github.com/ioneater/ESIBD-Explorer

Contact
-------

ioneater.dev@gmail.com